	/* wl (word length) -- print a table of word lengths from stdin */
%{
#define MAXLEN	1024
#undef yywrap		/* in case we use flex instead of lex */

long count[MAXLEN];	/* count[k] holds count of words of length k */
%}

%%
[_A-Za-z]+	count[(yyleng < (MAXLEN-1)) ? yyleng : (MAXLEN-1)]++;
.	|
\n	;
%%
yywrap()
{
    int i;
    long n;
    long cum_count;
    long max_count;
    long total;

    for (max_count = 0, total = 0, i = 0; i < MAXLEN; i++)
    {
	max_count = (count[i] > max_count) ? count[i] : max_count;
	total += count[i];
    }

    printf("Length  Word Count  Running Count (total = %ld)\n",total);

    for (cum_count = 0, i = 0; i < MAXLEN; i++)
    {
        if (count[i] > 0)
	{
	    cum_count += count[i];
	    printf("%4d%8ld%5.1lf%%%8ld%6.1lf%%", i, count[i], 
		100.0 * (double)count[i]/(double)total,
		cum_count,
		100.0 * (double)cum_count/(double)total);
	    putchar(' ');
	    for (n = 47L*count[i], n /= max_count; n > 0; --n)
	        putchar('#');
	    putchar('\n');
	}
    }
    return (i);    
}

